@@ -4,6 +4,8 @@ pub mod command {
     pub mod command_bus;
     pub mod bus_impl {
         pub mod command_dispatcher;
+        pub mod command_logging_middleware;
+        pub mod command_logging_middleware_test;
         mod command_dispatcher_test;
         pub mod event_produced_by_command_bus_dispatcher;
         mod event_produced_by_command_bus_dispatcher_test;
@@ -21,6 +23,8 @@ pub mod event {
     pub mod event_bus;
     pub mod event_handler;
     mod event_handler_test;
+    pub mod event_handler_logger;
+    pub mod event_handler_logger_test;
 }
 pub mod query {
     pub mod query;
@@ -31,6 +35,8 @@ pub mod query {
     pub mod bus_impl {
         pub mod query_dispatcher;
         mod query_dispatcher_test;
+        pub mod query_logging_middleware;
+        pub mod query_logging_middleware_test;
     }
 }
 mod test_tools {
@@ -41,9 +47,11 @@ mod test_tools {
     pub mod some_query_for_test;
     pub mod some_response_for_test;
     pub mod some_query_handler_for_test;
+    pub mod some_logger_for_test;
 }
 mod test_macro {
     mod command_macro_test;
     mod event_macro_test;
     mod query_macro_test;
-}
\ No newline at end of file
+}
+mod logger_test;
\ No newline at end of file
